@@ -7,7 +7,8 @@ use strict;
 
 package XML::Compile::Schema::BuiltInFacets;
 use vars '$VERSION';
-$VERSION = '0.80';
+$VERSION = '0.81';
+
 use base 'Exporter';
 
 our @EXPORT = qw/builtin_facet/;
@@ -223,7 +224,7 @@ sub _pattern($$$)
     }
 
     local $" = '|';
-    my $pat = qr/@pats/;
+    my $pat = qr/^(?:@pats)$/;
     my $err = $args->{err};
 
     sub { return $_[0] if $_[0] =~ $pat;
